# -*- coding: utf-8 -*-
from .art import *
from .art_dic import *
import sys
import doctest
import getopt

if __name__=="__main__":
    args=sys.argv
    if len(args)>1:
        if args[1].upper()=="TEST":
            doctest.testfile("test.py",optionflags=doctest.NORMALIZE_WHITESPACE | doctest.ELLIPSIS, verbose=True)
        elif args[1].upper()=="LIST":
            aprint_test()
        elif args[1].upper()=="FONTS":
            font_list()
        elif len(args)>2:
            if args[1].upper()=="TEXT":
                if len(args)>3:
                    tprint(args[2],font=args[3])
                else:
                    tprint(args[2])
            elif args[1].upper()=="SAVE":
                if len(args)>3:
                    tsave(args[2], font=args[3])
                else:
                    tsave(args[2])
            elif args[1].upper()=="SHAPE":
                aprint(args[2])
            else:
                help_func()
        else:
            help_func()
    else:
        help_func()






from distutils.core import setup
setup(
  name = 'artxy',
  packages = ['artxy'],
  version = '0.5',
  description = 'ASCII Art Collection In Python',
  long_description='ASCII Art Collection In Python',
  author = 'KingHS',
  author_email = '382771946@qq.com',
  url = 'https://github.com/kingheshan/xyart',
  download_url = 'https://github.com/kingheshan/xyart/archive/master.zip',
  keywords = ['ascii', 'art', 'python3','python','text'],
  install_requires=[
	  'codecov',
      ],
  classifiers=[
      'Development Status :: 3 - Alpha',
      'Intended Audience :: Developers',
      'Natural Language :: English',
      'License :: OSI Approved :: MIT License',
      'Operating System :: OS Independent',
      'Programming Language :: Python :: 3.4',
      'Programming Language :: Python :: 3.5',
      'Programming Language :: Python :: 3.6',
      'Topic :: Text Processing :: Fonts',
    ],
  license='MIT',
)
